import os
from dotenv import load_dotenv

# Load environment variables from .env file
load_dotenv()

# API Configuration
API_KEY = os.getenv("API_KEY")
if not API_KEY:
    raise EnvironmentError("API_KEY environment variable is not set. Please check your .env file.")

API_SECRET = os.getenv("API_SECRET")
if not API_SECRET:
    raise EnvironmentError("API_SECRET environment variable is not set. Please check your .env file.")

BASE_ENDPOINT = os.getenv("BASE_ENDPOINT", "https://api.pamoja.team")
AUTH_ENDPOINT = f"{BASE_ENDPOINT}/auth/v1/token"
CHATS_ENDPOINT = f"{BASE_ENDPOINT}/conversations/v1/chats"
MESSAGES_ENDPOINT = f"{BASE_ENDPOINT}/conversations/v1/messages"
REFRESH_TOKEN_ENDPOINT = f"{BASE_ENDPOINT}/auth/v1/refresh"

# Database and storage configuration
DATABASE_PATH = os.getenv("DATABASE_PATH", "messages.db")
IMAGE_SAVE_PATH = os.getenv("IMAGE_SAVE_PATH", "static/images")
VIDEOS_SAVE_PATH = os.getenv("VIDEOS_SAVE_PATH", "static/videos")

os.makedirs(IMAGE_SAVE_PATH, exist_ok=True)
os.makedirs(VIDEOS_SAVE_PATH, exist_ok=True)

# Fetch configuration
FETCH_INTERVAL_MINUTES = int(os.getenv("FETCH_INTERVAL_MINUTES", "2"))

# Pagination
MESSAGES_PER_PAGE = int(os.getenv("MESSAGES_PER_PAGE", "20"))

# Time zones
TIME_ZONES = {
    'NAIROBI': os.getenv("DEFAULT_TIMEZONE", "Africa/Nairobi")
}
